package VMOMI::DeviceNotSupportedReason;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
